pub struct SharedExponentialHistogram { /* private fields */ }Expand description
An ExponentialHistogram with interior mutability
Implementations
Sourcepub fn accumulate(&self, value: f64)
pub fn accumulate(&self, value: f64)
Observe a value, increasing its bucket’s count by 1
Sourcepub fn snapshot(&self) -> ExponentialHistogram
pub fn snapshot(&self) -> ExponentialHistogram
Get the current snapshot of the histogram. This gives you an owned clone of the backing histogram at a point in time, so you can work with it without holding a lock.
Sourcepub fn snapshot_and_reset(&self) -> ExponentialHistogram
pub fn snapshot_and_reset(&self) -> ExponentialHistogram
Get the current snapshot of the histogram. This gives you an owned clone of the backing histogram at a point in time, so you can work with it without holding a lock.